from near_jsonrpc_models.rpc_gas_price_request import RpcGasPriceRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForGasPrice(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['gas_price']
    params: RpcGasPriceRequest



from near_jsonrpc_models.internal_error import InternalError
from near_jsonrpc_models.rpc_request_validation_error_kind import RpcRequestValidationErrorKind
from near_jsonrpc_models.rpc_view_gas_key_error import RpcViewGasKeyError
from pydantic import BaseModel
from pydantic import RootModel
from typing import Literal
from typing import Union


class ErrorWrapperForRpcViewGasKeyErrorRequestValidationError(BaseModel):
    cause: RpcRequestValidationErrorKind
    name: Literal['REQUEST_VALIDATION_ERROR']

class ErrorWrapperForRpcViewGasKeyErrorHandlerError(BaseModel):
    cause: RpcViewGasKeyError
    name: Literal['HANDLER_ERROR']

class ErrorWrapperForRpcViewGasKeyErrorInternalError(BaseModel):
    cause: InternalError
    name: Literal['INTERNAL_ERROR']

class ErrorWrapperForRpcViewGasKeyError(RootModel[Union[ErrorWrapperForRpcViewGasKeyErrorRequestValidationError, ErrorWrapperForRpcViewGasKeyErrorHandlerError, ErrorWrapperForRpcViewGasKeyErrorInternalError]]):
    pass




from near_jsonrpc_models.ext_costs_config_view import ExtCostsConfigView
from near_jsonrpc_models.limit_config import LimitConfig
from near_jsonrpc_models.storage_get_mode import StorageGetMode
from near_jsonrpc_models.vmkind import VMKind
from pydantic import BaseModel
from pydantic import conint


class VMConfigView(BaseModel):
    # See [VMConfig::deterministic_account_ids](crate::vm::Config::deterministic_account_ids).
    deterministic_account_ids: bool = None
    # See [VMConfig::discard_custom_sections](crate::vm::Config::discard_custom_sections).
    discard_custom_sections: bool = None
    # See [VMConfig::eth_implicit_accounts](crate::vm::Config::eth_implicit_accounts).
    eth_implicit_accounts: bool = None
    # See [VMConfig::eth_implicit_global_contract](crate::vm::Config::eth_implicit_global_contract).
    eth_implicit_global_contract: bool = None
    # Costs for runtime externals
    ext_costs: ExtCostsConfigView = None
    # See [VMConfig::fix_contract_loading_cost](crate::vm::Config::fix_contract_loading_cost).
    fix_contract_loading_cost: bool = None
    # See [VMConfig::gas_key_host_fns](crate::vm::Config::gas_key_host_fns).
    gas_key_host_fns: bool = None
    # See [VMConfig::global_contract_host_fns](crate::vm::Config::global_contract_host_fns).
    global_contract_host_fns: bool = None
    # Gas cost of a growing memory by single page.
    grow_mem_cost: conint(ge=0, le=4294967295) = None
    # Deprecated
    implicit_account_creation: bool = None
    # Describes limits for VM and Runtime.
    # 
    # TODO: Consider changing this to `VMLimitConfigView` to avoid dependency
    # on runtime.
    limit_config: LimitConfig = None
    # Base gas cost of a linear operation
    linear_op_base_cost: conint(ge=0, le=18446744073709551615) = None
    # Unit gas cost of a linear operation
    linear_op_unit_cost: conint(ge=0, le=18446744073709551615) = None
    # See [VMConfig::reftypes_bulk_memory](crate::vm::Config::reftypes_bulk_memory).
    reftypes_bulk_memory: bool = None
    # Gas cost of a regular operation.
    regular_op_cost: conint(ge=0, le=4294967295) = None
    # See [VMConfig::storage_get_mode](crate::vm::Config::storage_get_mode).
    storage_get_mode: StorageGetMode = None
    # See [VMConfig::vm_kind](crate::vm::Config::vm_kind).
    vm_kind: VMKind = None



"""Configuration for dynamic resharding feature
See [`DynamicReshardingConfig`] for more details."""

from near_jsonrpc_models.shard_id import ShardId
from pydantic import BaseModel
from pydantic import conint
from typing import List


class DynamicReshardingConfigView(BaseModel):
    # Shards that should **not** be split even when they meet the regular split criteria.
    block_split_shards: List[ShardId]
    # Shards that should be split even when they don't meet the regular split criteria.
    force_split_shards: List[ShardId]
    # Maximum number of shards in the network.
    max_number_of_shards: conint(ge=0, le=18446744073709551615)
    # Memory threshold over which a shard is marked for a split.
    memory_usage_threshold: conint(ge=0, le=18446744073709551615)
    # Minimum memory usage of a child shard.
    min_child_memory_usage: conint(ge=0, le=18446744073709551615)
    # Minimum number of epochs until next resharding can be scheduled.
    min_epochs_between_resharding: conint(ge=0, le=18446744073709551615)



"""A part of a state for the current head of a light client. More info [here](https://nomicon.io/ChainSpec/LightClient)."""

from near_jsonrpc_models.crypto_hash import CryptoHash
from pydantic import BaseModel
from pydantic import conint


class BlockHeaderInnerLiteView(BaseModel):
    # The merkle root of all the block hashes
    block_merkle_root: CryptoHash
    # The epoch to which the block that is the current known head belongs
    epoch_id: CryptoHash
    height: conint(ge=0, le=18446744073709551615)
    # The hash of the block producers set for the next epoch
    next_bp_hash: CryptoHash
    # The epoch that will follow the current epoch
    next_epoch_id: CryptoHash
    outcome_root: CryptoHash
    prev_state_root: CryptoHash
    # Legacy json number. Should not be used.
    timestamp: conint(ge=0, le=18446744073709551615)
    timestamp_nanosec: str



from near_jsonrpc_models.error_wrapper_for_rpc_split_storage_info_error import ErrorWrapperForRpcSplitStorageInfoError
from near_jsonrpc_models.rpc_split_storage_info_response import RpcSplitStorageInfoResponse
from pydantic import BaseModel
from pydantic import RootModel
from typing import Union


class JsonRpcResponseForRpcSplitStorageInfoResponseAndRpcSplitStorageInfoErrorResult(BaseModel):
    id: str
    jsonrpc: str
    result: RpcSplitStorageInfoResponse

class JsonRpcResponseForRpcSplitStorageInfoResponseAndRpcSplitStorageInfoErrorError(BaseModel):
    id: str
    jsonrpc: str
    error: ErrorWrapperForRpcSplitStorageInfoError

class JsonRpcResponseForRpcSplitStorageInfoResponseAndRpcSplitStorageInfoError(RootModel[Union[JsonRpcResponseForRpcSplitStorageInfoResponseAndRpcSplitStorageInfoErrorResult, JsonRpcResponseForRpcSplitStorageInfoResponseAndRpcSplitStorageInfoErrorError]]):
    pass




from near_jsonrpc_models.rpc_view_access_key_request import RpcViewAccessKeyRequest
from pydantic import BaseModel
from typing import Literal


class JsonRpcRequestForExperimentalViewAccessKey(BaseModel):
    id: str
    jsonrpc: str
    method: Literal['EXPERIMENTAL_view_access_key']
    params: RpcViewAccessKeyRequest
